pub enum BufferError {
ArenaFull,
InvalidState,
Codec(CodecError),
}Expand description
Variants
ArenaFull
The arena is too small to hold even one slot.
InvalidState
The state type T has drop logic, which is not supported.
Codec(CodecError)
An error occurred in the bitstream codec.